@@ -86,7 +86,9 @@ OC.L10N.register(
     "Undo delete feed" : "Razveljavi brisanje vira",
     "Rename" : "Preimenuj",
     "Menu" : "Meni",
+    "Pin to top" : "Pripni na vrh",
     "Enable full text" : "Omogoči polno besedilo",
+    "Disable full text" : "Omogoči polno besedilo",
     "Delete" : "Izbriši",
     "Dismiss" : "Opusti",
     "Collapse" : "Skrči",
